@@ -1,5 +1,5 @@
 #
-# $Id: IMDB.pm,v 1.42 2003/12/31 19:13:34 epaepa Exp $
+# $Id: IMDB.pm,v 1.46 2004/05/15 02:39:03 jveldhuis Exp $
 #
 # The IMDB file contains two packages:
 # 1. XMLTV::IMDB::Cruncher package which parses and manages IMDB "lists" files
@@ -890,7 +890,7 @@ sub applyFound($$$)
 		my $name=$idInfo->{title};
 		my $found=0;
 		for my $v (@{$prog->{title}}) {
-		    if ( $v->[0]=~m/^$name$/i ) {
+		    if ( lc($v->[0]) eq lc($name) ) {
 			$found=1;
 		    }
 		    else {
@@ -971,7 +971,7 @@ sub applyFound($$$)
 		    for my $name (@{$prog->{credits}->{director}}) {
 			my $found=0;
 			for(@list) {
-			    if ( m/^$name$/i ) {
+			    if ( lc eq lc($name) ) {
 				$found=1;
 			    }
 			}
@@ -1005,7 +1005,7 @@ sub applyFound($$$)
 		for my $name (@{$prog->{credits}->{actor}}) {
 		    my $found=0;
 		    for(@list) {
-			if ( m/^$name$/i ) {
+			if ( lc eq lc($name) ) {
 			    $found=1;
 			}
 		    }
@@ -1077,7 +1077,7 @@ sub applyFound($$$)
 		my $found=0;
 		#print "checking category $value->[0] with $mycategory\n";
 		for my $c (@categories) {
-		    if ( $c->[0]=~m/^$value->[0]$/i ) {
+		    if ( lc($c->[0]) eq lc($value->[0]) ) {
 			$found=1;
 		    }
 		}
@@ -1402,7 +1402,9 @@ sub closeMaybeGunzip($$)
 	#
 	#return gunzip_close($_[1]);
     }
-    return close($_[1]);
+
+    # Apparently this can also segfault (wtf?).
+    #return close($_[1]);
 }
 
 sub readMoviesOrGenres($$$$)
@@ -1813,7 +1815,7 @@ sub dbinfoSave($)
 {
     my $self=shift;
     open(INFO, "> $self->{moviedbInfo}") || return(1);
-    for (keys %{$self->{dbinfo}}) {
+    for (sort keys %{$self->{dbinfo}}) {
 	print INFO "".$_.":".$self->{dbinfo}->{$_}."\n";
     }
     close(INFO);
@@ -1828,7 +1830,7 @@ sub invokeStage($$)
     my $startTime=time();
     if ( $stage == 1 ) {
 	$self->status("parsing Movies list for stage $stage..");
-	my $countEstimate=370000;
+	my $countEstimate=398000;
 	my $num=$self->readMoviesOrGenres("Movies", $countEstimate, "$self->{imdbListFiles}->{movies}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -1879,7 +1881,7 @@ sub invokeStage($$)
     elsif ( $stage == 2 ) {
 	$self->status("parsing Directors list for stage $stage..");
 
-	my $countEstimate=75500;
+	my $countEstimate=85000;
 	my $num=$self->readCastOrDirectors("Directors", $countEstimate, "$self->{imdbListFiles}->{directors}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -1946,7 +1948,7 @@ sub invokeStage($$)
 	$self->status("parsing Actors list for stage $stage..");
 
 	#print "re-reading movies into memory for reverse lookup..\n";
-	my $countEstimate=460000;
+	my $countEstimate=508000;
 	my $num=$self->readCastOrDirectors("Actors", $countEstimate, "$self->{imdbListFiles}->{actors}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -1997,7 +1999,7 @@ sub invokeStage($$)
     elsif ( $stage == 4 ) {
 	$self->status("parsing Actresses list for stage $stage..");
 
-	my $countEstimate=280000;
+	my $countEstimate=308000;
 	my $num=$self->readCastOrDirectors("Actresses", $countEstimate, "$self->{imdbListFiles}->{actresses}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2047,7 +2049,7 @@ sub invokeStage($$)
     }
     elsif ( $stage == 5 ) {
 	$self->status("parsing Genres list for stage $stage..");
-	my $countEstimate=250000;
+	my $countEstimate=271000;
 	my $num=$self->readMoviesOrGenres("Genres", $countEstimate, "$self->{imdbListFiles}->{genres}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2097,7 +2099,7 @@ sub invokeStage($$)
     }
     elsif ( $stage == 6 ) {
 	$self->status("parsing Ratings list for stage $stage..");
-	my $countEstimate=76000;
+	my $countEstimate=85000;
 	my $num=$self->readRatings($countEstimate, "$self->{imdbListFiles}->{ratings}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2710,8 +2712,8 @@ sub crunchStage($$)
 	}
 	else {
 	    $self->status("prep stage $stage succeeded with $self->{errorCountInLog} errors in $self->{imdbDir}/stage$stage.log");
-	    if ( $stage == 7 && $self->{errorCountInLog} > 30 && $self->{errorCountInLog} < 50 ) {
-		$self->status("this stage commonly produces around 44 (or so) warnings because of imdb");
+	    if ( $stage == 7 && $self->{errorCountInLog} > 30 && $self->{errorCountInLog} < 60 ) {
+		$self->status("this stage commonly produces around 49 (or so) warnings because of imdb");
 		$self->status("list file inconsistancies, they can usually be safely ignored");
 	    }
 	}
